Monty Python's Flying Circus: Just the Words - Episode 39

# Episode Thirty-nine: Grandstand

Thames TV introduction
'Light Entertainment Awards'
Dickie Attenborough
The Oscar Wilde sketch
David Niven's fridge
Pasolini's film 'The Third Test Match'
New brain from Curry's
Blood donor
International Wife-Swapping
Credits of the Year
The dirty vicar sketch

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Begin with Thames Television logo and fanfare. Cut to David Hamilton in their presentation studios.
David Hamilton | Good evening. We've got an action packed evening for you tonight on Thames, but right now here's a rotten old BBC programme.
| Cut to the nude man (Terry J) at the organ.
Announcer | And now...
It's Man | It's...
| Cut to a photo of Piccadilly Circus.
| SUPERIMPOSED CAPTIONS: 'THE BRITISH SHOWBIZ AWARDS' 'PRESENTED BY HRH THE DUMMY PRINCESS MARGARET'
| We mix through to the dummy Princess Margaret at a desk, as for awards ceremony. At the desk also, on either side of her, two men in dinner jackets and a pantomime goose. Bill Cotton is nowhere to be seen. High up above them, there is a screen. Enter Dickie Attenborough.
Dickie | Ladies and gentlemen, Mr Chairman, friends of the society, your dummy Royal Highness. Once again, the year has come full circle, and for me there can be no greater privilege, and honour, than to that to which it is my lot to have befallen this evening. There can be no finer honour than to welcome into our midst tonight a guest who has not only done only more than not anyone for our Society, but nontheless has only done more. He started in the film industry in 1924, he started again in 1946, and finally in 1963. He has been dead for four years, but he has not let that prevent him from coming here this evening. (he gets out an onion and holds it to his eyes; tears pour out) Ladies and gentlemen, no welcome could be more heartfelt than that which I have no doubt you will all want to join with me in giving this great showbiz stiff. Ladies and gentlemen, to read the nominations for the Light Entertainment Award, the remains of the late Sir Alan Waddle.
| There is awful continuity music. Terrific applause. Attenborough weeps profusely. A man in a brown coat comes in carrying a white five-foot plinth. He puts it down. Behind him comes another man carrying a bronze funeral urn. It has a black tie on. Cut to stock film of the audience standing in rapturous applause. The urn is put on top of the plinth and a microphone is placed in front of it. Slight pause. Cut to Dickie weeping profusely. The urn clears its throat.
The Urn | (silly voice) The nominations are Mr Edward Heath, for the new suit sketch, (zoom quickly in to film on the screen of the lady of Brussels throwing ink all over Mr Heath; cut back to the hall for applause) Mr Richard Baker for Lemon Curry.
| Cut to Richard Baker
Richard Baker | Lemon Curry?
| Cut back to the urn.
The Urn | And the Third Parachute Brigade Amateur Dramatic Society for the Oscar Wilde skit.
| Zoom in to overlay showing some stock film of hansom caps galloping past.
| SUPERIMPOSED CAPTION: 'LONDON 1895'
| SUPERIMPOSED CAPTION: 'THE RESIDENCE OF MR OSCAR WILDE'
| Suitably classy music starts. Mix through to Wilde's drawing room. A crowd of suitably dressed folk are engaged in typically brilliant conversation, laughing affectedly and drinking champagne.
Prince | My congratulations, Wilde. Your latest play is a great success. The whole of London's talking about you.
Oscar | There is only one thing in the world worse than being talked about, and that is not being talked about.
| There follows fifteen seconds of restrained and sycophantic laughter.
Prince | Very very witty ... very very witty.
Whistler | There is only one thing in the world worse than being witty, and that is not being witty.
| Fifteeen more seconds of the same.
Oscar | I wish I had said that.
Whistler | You will, Oscar, you will. (more laughter)
Oscar | Your Majesty, have you met James McNeill Whistler?
Prince | Yes, we've played squash together.
Oscar | There is only one thing worse than playing squash together, and that is playing it by yourself. (silence) I wish I hadn't said that.
Whistler | You did, Oscar, you did. (a little laughter)
Prince | I've got to get back up the Palace.
Oscar | Your Majesty is like a big jam doughnut with cream on the top.
Prince | I beg your pardon?
Oscar | Um ... It was one of Whistler's.
Whistler | I never said that.
Oscar | You did, James, you did.
| The Prince of Wales stares expectantly at Whistler.
Whistler | ... Well, Your Highness, what I meant was that, like a doughnut, um, your arrival gives us pleasure and your departure only makes us hungry for more. (laughter) Your Highness, you are also like a stream of bat's piss.
Prince | What?
Whistler | It was one of Wilde's. One of Wilde's.
Oscar | It sodding was not! It was Shaw!
Shaw | I ... I merely meant, Your Majesty, that you shine out like a shaft of gold when all around is dark.
Prince | (accepting the compliment) Oh.
Oscar | (to Whistler) Right. Right? (to Prince) Your Majesty is like a dose of clap.
Whistler | Before you arrive - before you arrive is pleasure, and after is a pain in the dong.
Prince | What?
Oscar and Whistler | One of Shaw's, one of Shaw's.
Shaw | You bastards. Um ... what I meant, Your Majesty, what I meant ...
Oscar | We've got him, Jim.
Whistler | Come on, Shaw-y.
Oscar | Come on, Shaw-y.
Shaw | I merely meant ...
Oscar | Come on, Shaw-y.
Whistler | Let's have a bit of wit, then, man.
Oscar | Come on, Shaw-y.
Shaw | (blows a raspberry)
| The Prince shakes Shaw's hand. Laughter all round. We then link to animation for a few minutes, then back to Dickie Attenborough at the awards ceremony. He nows has bunches of onions slung around his neck.
Dickie | Ladies and gentlemen, seldom can it have been a greater pleasure and privilege than it is for me now to announce that the next award gave me the great pleasure and privilege of asking a man without whose ceaseless energy and tireless skill the British Film Indusrty would be today. I refer of course to my friend and colleague, Mr David Niven. (vast applause, a bit of emotion from Dickie) Sadly, David Niven cannot be with us tonight, but he has sent his fridge. (applause; 'Around the world in eighty days' music; the fridge is pushed down by a man in a brown coat) This is the fridge in which David keeps most of his milk, butter and eggs. What a typically selfless gesture, that he should send this fridge, of all his fridges, to be with us tonight.
Fridge | (the same silly voice) The nominations for the best Foreign Film Director are: Monsieur Richad Attenborough, Ricardo de Attenbergie, Rik Artenborough, Ri Char Dat En Bollo, and Pier Paolo Pasolini.
Dickie | Before we hear the joint winner, let's see the one that came sixth. Let us see Pier Paolo Pasolini's latest film.
| Close up of grass on cricket pitch. In the background we hear the buzzing of insects. A cricket ball rolls into shot and a hand reaches down and picks it up. Pull out to reveal he is a bowler, behind him a couple of fielders. He is shot from low down.
| CAPTION: 'PASOLINI'S THE THIRD TEST MATCH'
| Close up on the bowler as he turns to look at his field. Cut to a skeleton on the boundary in tattered remnants of cricket gear. Noise of flies buzzing becomes louder. Sounds of mocking laughter. Cut to the bowler in close up turning in the direction of the laughter. Shot of the batsman at his crease, but behind him the wicket keeper and first slip are monks in brown cowls. They are laughing at him. Cut back to the bowler's horrified eyes, he looks again. Cut to the same shot of the batsman only now the wicket keeper and first slip are cricketers again. Wind, buzzing. Cut back to the bowler, who starts to rub the ball on his trousers. Music comes in. Close up bowler's face starting to sweat. Close up ball rubbing on trousers. Close up face sweating. Cut to a girl in the pavilion licking her lips. Cut back to ball rubbing. Cut to his sweating face. Cut to girl. Cut back to bowler as he starts his run. Close up of bowler running. He runs over a couple making love in the nude. Mounting music. Cut back to the bowler, as he releases ball. Cut to the ball smashing into stumps. The music reaches crescendo. Silence. In slow motion the bowler turns, arms outstretched to the umpire. The umpire turns into a cardinal who produces a cross and holds it up like a dismissal sign. Cut to vociferous group of cricketers in a TV studio. They are all in pads and white flannels. They are on staggered rostra as in 'Talk-back'. Facing them is Pier Paolo Pasolini.
First Cricketer | There's lots of people making love, but no mention af Geoff Boyott's average.
Pasolini | (italian accent) Who is-a Geoff Boycott?
| SUPERIMPOSED CAPTION: 'PIER PAOLO PASOLINI'
Second Cricketer | And in t'film, we get Fred Titmus...
Pasolini | Si, Titmus, si, si...
| SUPERIMPOSED CAPTION: 'YORKSHIRE'
Second Cricketer | ...the symbol of man's regeneration through radical Marxism...fair enough...but we never once get a chance to see him turn his off-breaks on that Brisbane sticky.
Third Cricketer | Aye, and what were all that dancing through Ray Illingworth's innings? Forty-seven not out and the bird comes up and feed him some grapes!
| General cricketorial condemnation. We pull back to show that it is on a television set in an ordinary sitting room. Two pepperpots are watching the television. They are both called Mrs Zambesi.
First Zambesi | What's on the other side?
| The second Mrs Zambesi gets up and switches channels to reveal Dickie Attenborough still at it.
Dickie Attenborough | Nobody could be prouder than...
Second Zambesi | Ugh! (she switches the set off)
First Zambesi | Um, shall we go down and give blood?
Second Zambesi | Oh, I don't want a great bat flapping round my neck.
First Zambesi | They don't do it like that! They take it from your arm!
Second Zambesi | I can't give it. I caught swamp fever in the Tropics.
First Zambesi | You've never even been to the Tropics. You've never been south of Sidcup.
Second Zambesi | You can catch it off lampposts.
First Zambesi | Catch what?
Second Zambesi | I don't know, I'm all confused.
First Zambesi | You ought to go and see a psychiatrist. You're a loony. You might even need a new brain.
Second Zambesi | Oh, I couldn't afford a whole new brain.
First Zambesi | Well, you could get one of those Curry's brains.
Second Zambesi | How much are they?
First Zambesi | (picking up a catalogue) I don't know. I'll have a look in the catalogue. Here we are. (she thumbs through it) Battery lights, dynamo lights, rear lights, brains - here we are...
Second Zambesi | I'm still confused.
First Zambesi | Oh, there's a nice one here, thirteen-and-six, it's one of Curry's own brains.
| CAPTION: 'OLD SKETCH WRITTEN BEFORE DECIMALISATION'
Second Zambesi | That one looks nice, what's that?
First Zambesi | That's a mudguard!
Second Zambesi | It's only eight bob.
| CAPTION: '1np = 2½op'
First Zambesi | Aw, I think it's worth the extra five bob for the brain. I'll give them a ring. (she goes to the phone and dials one number) Hello, Curry's? I'd like to try one of your thirteen-and-sixpenny brains please. Yes... yes... yes, ye... um... (looks at her shoe) five-and-a-half... yes... thank you. (replaces phone) They're sending someone round. (there is a knock at the door)
Second Zambesi | Oh, that was quick. Come in.
Man | Er, hello Mr and Mrs and Mrs Zambesi?
First Zambesi | Yes, that's right. Are you the man from Curry's?
Man | No, I've just come to say that he's on his way. Would you sign this please.
| He hands a bare leg severed from the knee downwards round the door.
Man | Thank you very much.
First Zambesi | (she takes the pen from him but drops it) Ooh! (she picks it up and signs the leg)
Man | Thank you. Sorry to bother you.
First Zambesi | Thank you.
Man | Thank you.
First Zambesi | Thank you.
| The man goes. A knock at the door and he reappears.
Man | Um, he's just coming now.
First Zambesi | Thank you.
| Another knock at the door.
Second Zambesi | Come in!
Man | Here he is.
| The door opens and a dummy salesman is flung in, carrying a briefcase. He flops down on to the floor. The door shuts. The two pepperpots lean over and look at him for some time.
First Zambesi | Hello ... hello ...
Second Zambesi | (picking up the dummy) That's not a proper salesman. (she throws it down) I'm not buying one from him, he doesn't give you confidence.
First Zambesi | He doesn't give me any confidence at all - he's obviously a dummy. I'll ring Curry's. (she just picks up the phone without dialing this time) Hello, Curry's - that salesman you sent round is obviously a dummy... Oh, thank you very much. (she puts the phone down) They're sending round a real one. (a knock on the door)
Second Zambesi | Come in.
Salesman | Good morning - Mr and Mrs and Mrs Zambesi?
Second Zambesi | Yes, that's right.
First Zambesi | Yes, that's right ... (out of the side of the mouth in a man's voice) Yes that's right.
Salesman | (to dummy) All right, Rutherford, I'll take over.
| He opens a box and produces a device about the size of a small teapot with various gadgets and wires on it.
Second Zambesi | Oh, that's nice.
Salesman | Yes, we sell a lot of these. Right, shall we try a fitting?
Second Zambesi | Oh, do I have to have an operation?
| He starts to put it on her head.
Salesman | No, madam, you just strap it on.
Second Zambesi | Doesn't it go inside my head?
Salesman | Not the Roadster, madam, no. You're thinking of the Brainette Major.
Second Zambesi | How much is that?
Salesman | Forty-four-and-six.
| CAPTION: '44/6d = £2.22½p'
Second Zambesi | Oh no, it's not worth it.
Salesman | Not with the Curry's surgery we use, no, madam. (he gets out some tools) Now then. The best bet is the Bertrand Russell Super Silver. That's a real beauty - 250 quid plus hospital treatment.
First Zambesi | Oooh, that's a lot.
Salesman | It's colour. Right. (he begins to twiddle a few knobs; lights flash on occasionally as he does this) One, two, three, testing, testing.
Second Zambesi | Mince pie for me, please.
First Zambesi | What did she say that for?
Salesman | Quiet please. It's not adjusted yet. (he makes more adjustments)
Second Zambesi | Oh, I am enjoying this rickshaw ride. I've been a Tory all my life, my life, my life. Good morning Mr Presley. How well you look, you look very well ... our cruising speed is 610 miles per hour ... well well well porridge ... well well well, well, hello hello dear ... hello dear!
Salesman | Right, one, two, three ... (the salesman adjusts a switch)
Second Zambesi | ... eight, seven, (he adjusts another switch) four.
First Zambesi | Oh, she never knew that before.
Salesman | Quiet please. Mrs Zambesi, who wrote the theory of relativity?
First Zambesi | I know! I know.
Salesman | Quiet, please! (he adjusts a tuning control)
Second Zambesi | Einstane ... Einstone ... Einsteen ... Einston ... Einstin ... Einsten ... Einstein.
Salesman | Good.
Second Zambesi | Noël Einstein.
Salesman | Right. That'll be 13/6d please.
First Zambesi | (paying him with invisible money) That's marvelous.
Salesman | She can take it off at night, unless she wants to read, of course. And don't ask her too many questions because it will get hot. If you do have any trouble here is my card. (he reaches in his case and hands her the dismembered part of an arm) Give us a ring - give us a ring, and either myself, or Mr Rutherford, (he picks up the dummy) Good Bye.
First Zambesi | Thank you very much.
| As soon as the door is shut, the man's head pop around.
Man | He's gone now.
| He withdraws head and shuts the door.
First Zambesi | (tentatively) Shall we go down and give blood?
Second Zambesi | (with slightly glazed eyes) Yes, please Mr Roosevelt, but try and keep the noise to a minimum.
First Zambesi | I'll go and get your coat for you.
Second Zambesi | I'm quite warm in this stick of celery, thank you, Senator Muskie.
| The pepperpots appear out of their gate and walk down the street. We follow them closely.
Second Zambesi | (to neighbour) Stapling machine, Mr Clarke.
First Zambesi | (explaining) New brain.
Second Zambesi | Stapling machine, Mrs Worral.
| Cut to a pepperpot with identical brain strapped on head.
Mrs Worral | Stapling machine, Mrs Zambesi.
| They walk on passing a bus stop at which a penguin is standing reading a paper. One or two unexploded Scotsmen lie on the ground at various places.
First Zambesi | Are you sure that's working all right?
Second Zambesi | Yes, thank you dear. It's marvellous. I think if we can win one or two of the early primaries, we could split the urban Republican vote wide open.
First Zambesi | Um...here we are then.
| They go into a door marked 'Blood Donors'.
Second Zambesi | Well being President of the United States is something that I shall have to think about.
| They walk through and out of shot. A hospital lobby. A line of people are being ushered through. A sign says 'Blood Donors' with an arrow in the direction they're all going. Mr Samson is in a white coat.
Samson | Blood donors that way, please.
Donor | Oh thank you very much (joins the line).
Samson | Thank you. (Grimshaw comes up to him and whispers in his ear, Samson looks at him, slightly surprised) What? (Grimshaw whispers again) No. No, I'm sorry but no. (Grimshaw whispers again) No, you may not give urine instead of blood. (Grimshaw whispers again) No, well, I don't care if you want to. (Grimshaw whispers again) No. There is no such thing as a urine bank.
Grimshaw | Please.
Samson | No. We have no call for it. We've quite enough of it without volunteers coming in here donating it.
Grimshaw | Just a specimen.
Samson | No, we don't want a specimen. We either want your blood or nothing.
Grimshaw | I'll give you some blood if you'll give me...
Samson | What?
Grimshaw | A thing to do some urine in.
Samson | No, no, just go away please.
Grimshaw | Anyway, I don't want to give you any blood.
Samson | Fine, well you don't have to, you see, just go away.
Grimshaw | Can I give you some spit?
Samson | No.
Grimshaw | Sweat?
Samson | No.
Grimshaw | Earwax?
Samson | No, look, this is a blood bank - all we want is blood.
Grimshaw | All right, I'll give you some blood.
| He holds out a jar full of blood.
Samson | Wher did you get that?
Grimshaw | Today. It's today's.
Samson | What group is it?
Grimshaw | What groups are there?
Samson | There's A...
Grimshaw | It's A.
Samson | (sniffing the blood) Wait a moment. It's mine. This blood is mine! What are you doing with it?
Grimshaw | I found it.
Samson | You found it? You stole it out of my body, didn't you?
Grimshaw | No.
Samson | No wonder I'm feeling off-colour. (he starts to drink the blood; Grimshaw grabs the bottle) Give that back.
Grimshaw | It's mine.
Samson | It is not yours. You stole it.
Grimshaw | Never.
Samson | Give it back to me.
Grimshaw | All right. But only if I can give urine.
Samson | ...Get in the queue.
| Cut to John Rickman type person with hat which he raises. There are white rails behind him which might be a racecourse.
Rickman | Good afternoon and welcome to Wife-Swapping from Redcar. And the big news this morning is that the British boy Boris Rodgers has succeeded in swapping his nine-stone Welsh-born wife for a Ford Popular and a complete set of Dickens. Well now, I can see they're ready at the start and so let's go now over for the start of the 3.30.
| Cut to high shot of a street with about 10 houses on each side.
Rickman | And first let's catch up with the latest news of the betting.
| SUPERIMPOSED CAPTIONS:
'NO. 12 BETTY PARKINSON | 7/4 ON FAV
NO. 27 MRS E. COLYER | 9/4
NO. 14 MRS CASEY | 4/1
| 5/1 BAR'
Voice Over | Number 12 Betty Parkinson 7 to 4 on favourite, number 27 Mrs Colyer 9 to 4, 5 to 1 bar those.
Rickman | And here's the starter Mrs Alec Marsh, (she climbs onto a rostrum and fires a gun) and they're off.
| One of the doors opens and a lady rushes across the street into another house. Other doors start opening up and down the street, wiith ladies criss-crossing out of each others houses. About twenty seconds of this high activity.
Rickman | And Mrs Rodgers is the frirst to show, there she goes into Mr Johnson's, and Mrs Johnson across too Mr Colyer, followed closely by Mrs Casey on the inside. Mrs Parkinson, number 12, going well there into Mr Webster's from the Co-op, Mrs Colyer's making ground fast after a poor start, she's out of Mr Casey's into Mr Parkinson's, she's a couple og lengths ahead of Mrs Johnson who's still not out of Mr Casey's. Mrs Penguin and Mrs Colyer - these two now at the head of the field from Mrs Brown, Mrs Atkins, Mrs Parkinson, Mrs Warner and Mrs Rudd - all still at Mr Phillip's. Mrs Penguin making the running now, challenged strongly by Mrs Casey, Mars Casey coming very fast on the inside, it's going to be Mrs Casey coming from behind. Now she's making a break on the outside, Mrs Penguin running...and at the line it's Mrs Casey who's got it by a short head from Mrs Penguin in second place, Mrs Parkinson in third, Mrs Rudd, Mrs Colyer, Mrs Warner and there's Mrs Griffiths who's remained unswapped.
| One lady is left in the middle of the road. Cut back to Rickman at the course railing.
Rickman | Well, a very exciting race there, and I have with me now the man who owned and trained the winner, Mrs Casey - Mr Casey. Well done, Jack.
Mr Casey | Thank you, John.
Rickman | Well, were you at all surprised about this, Jack?
Mr Casey | No, not really, no she's been going very well in training, and at Doncaster last week, and I fancy her very strongly for the Cheltenham weekend.
Rickman | Well, thank you very much indeed, Jack. We must leave you now because it's time for the team event.
| Peter West type figure in a white DJ sitting at a ballroom side table. He has one or two ballroom dancers beside him.
| SUPERIMPOSED TITLES: 'COME WIFE-SWAPPING - NORTH WEST V THE SOUTH EAST'
Peter | Hello, and a very warm welcome from the Tower ballroom suite at Reading, where there's very little in it, they're neck and neck, crop and grummit, real rack and saddle, brick and bucket, horse and tooth, cap and thigh, arse over tip, they're absolutely birds of a feather, there's not a new pin in it, you couldn't get a melon between them. Well, now, everything rests on the formation event and here come North West with the Mambo.
| Cut to line of ballroom dancers being led out. Four gentlemen and four ladies in each team, sixteen altogether.
Peter | Maestro, take it away, please.
| The dancers form up in two lines opposite each other, as though they are about to dance. The ladies are in nasty tulle, the gents in tails, with numbers on their backs. At the back of the hall a large banner says 'Mecca Wife-Swapping'. Mambo music starts its intro. After four bars the two teams starts grapping each other and wrestling on the ground. A vast orgy breaks out as they roll all over the floor. Cut quickly to Frank Bough in the 'Sportsview' studio.
Frank Bough | And now it's time for Rugby League, and highlights of this afternoon's game between Keighley and Hull Kingston Rovers.
| Cut to a field where mud-caked rugby league players in hooped shirts are getting ready for a scrum.
Eddie Waring | (voice over) Well, good afternoon and as you can see, Hull Kingston Rovers are well in the lead, it's a scrum down on the twenty-five, Keighley's Tom Colyer with the put in, Mrs Colyer to be put.
| The scrum has formed up, the scrum half has a dummy woman, small and light, but real looking, tucked under his arm, while he steadies the scrum. He puts her into the scrum, and after a lot of kicking she is eventually heeled out.
Eddie Waring | And there goes his wife into the scrum. And Hull have got the heel against the head. Doing nicely with this scrum, some very good packing here. Warrington's picked her up, is he going to let her go, Wrigley's with him, grand lad is this.
| Mrs Colyer is picked up by the scrum half who makes a run with her. Handing off a strong tackle and dodging with her, he side steps amd slips Mrs Colyer to a back who makes a run through and touches her down between the posts. They leave the lady dumped down between the posts and rush to congratulate and hug each other.
Eddie Waring | Well, that was right on the whistle, Rovers walkin' it there, winnin' easily by twenty-six points to two.
| Cut to Frank Bough again in the 'Sportsview' set.
Frank Bough | Just a reminder that on 'Match of the Day' tonight you can see highlights of two of this afternoon's big games. Mrs Robinson v Manchester United and Southampton v Mr Rogers, a rather unusual game that. And here's a late result...Convetry nil, Mr Johnson's Una three - Coventry going down at home, there. Just a little reminder that the next sport you can see on BBS 1 will be 9.20 on Wednesday night, when 'Wife Swapping with Coleman' comes live from my place. Till then, goodnight.
| Credits roll over four screens of naughty activity to the 'Grandstand' signature tune.
| GRANDSTAND A BBC INSIDE BROADCAST CONCEIVED WRITTEN AND PERFORMED BY MICHAEL PALIN AND MRS CLEESE ERIC IDLE AND MRS PALIN JOHN CLEESE AND MRS JONES TERRY GILLIAM AND TERRY JONES AND MRS IDLE GRAHAM CHAPMAN AND MR SHERLOCK ALSO APPEARING CAROL CLEVELAND AND MR AND MRS AND MRS ZAMBESI CARON GARDNER AND MR A. MAKE-UP BY MISS GAFFNEY AND MR LAST COSTUMES HAZEL PETHIG AND MR CLARKE GRAPHICS BY BOB BLAGDEN AND 'NAUGHTY' ROSY ANIMATIONS BY TERRY GILLIAM AND RABBI COLQUHOUN FILM CAMERAMAN ALAN FEATHERSTONE AND MISS WESTON FILM EDITOR MR RAY MILLICHOPE AND HIS ORCHESTRA SOUND RICHARD CHUBB AND MRS LIGHTING CHOREOGRAPHY BY JEAN CLARKE AND AN UNNAMED MAN IN ESHER DESIGNED BY CHRIS THOMPSON AND MRS ARMSTRONG-JONES PRODUCED BY IAN MACNAUGHTON AND 'DICKIE' A BBC TV AND MRS THAMES PRODUCTION
| Pull out from screen to see that this is on the screen in the awards set and Dickie is working a stirrup pump which pumps tears out from the side of his head via rather obvious tubes.
Dickie | There they go, the credits of the year. Credits that you and the Society voted as the credits that brought the most credit to the Society. Sadly, the man who designed them cannot be with us tonight, as he is at home asleep, but we are going to wake him up and tell him the good news.
| We see a darkened bedroom. The light is suddenly switched on. A man sits up. He has no clothes on.
Dickie | Are you there in Bristol, Arthur Briggs...?
| Briggs looks terrified. We see that another man (John) is in bed with him.
Briggs | Oh, my God! (pulls a sheet over the other man)
| Cut back to Dickie.
Dickie | And now for the moment you've all been waiting for...
| CAPTION: THE END
Dickie | No, not that moment. Although that moment is coming, in a moment. The moment I'm talking about is the moment when we present the award for the cast with the most awards award, and this year is no exception. Ladies and gentlemen will you join me and welcome please, the winners of this year's Mountbatten trophy, Showbusiness's highest accolade, the cast of the dirty Vicar sketch.
| Very patriotic music. The cast of the Dirty Vicar sketch come on. They curtsy to Princess Margaret. Attenborough embraces them all.
Dickie | Well now, let us see the performances which brought them this award. Let us see the Dirty Vicar sketch.
| Cut to two ladies taking tea in an Edwardian drawing room.
First Lady | Have you seen Lady Windermere's new carriage, dear?
Second Lady (Caron Gardener) | Absolutely enchanting!
First Lady | Isn't it!
| Chivers the butler enters.
Chivers | The new vicar to see you, m'lady.
First Lady | Send him in, Chivers.
Chivers | Certainly, m'lady. (he goes)
| Enter a Swiss mountaineer (Terry G) in Tyrolean hat, lederhosen, haversack, icepick, etc. Followed by two men in evening dress. They look round and exit.
First Lady | Now, how is your tea, dear? A little more water perhaps?
Second Lady | Thank you. It is delightful as it is.
Chivers | The Reverend Ronald Simms, the Dirty Vicar of St Michael's ... ooh!
| Chivers is obviously goosed from behind by the Dirty Vicar.
Vicar | Cor, what a lovely bit of stuff. I'd like to get my fingers around those knockers.
| He pounces upon the second lady, throws her skirt over her head and pushes her over the back of the sofa.
First Lady | How do you find the vicarage?
| The vicar stands up from behind the sofa, his shirt open and his hair awry; he reaches over and puts his hand down the first lady's front.
Vicar | I like tits!
First Lady | Oh vicar! vicar!
| The vicar suddenly pulls back and looks around him as if in the horror of dawning realisation.
Vicar | Oh my goodness. I do beg your pardon. How dreadful! The first day in my new parish, I completely ... so sorry!
First Lady | (adjusting her dress) Yes. Never mind, never mind. Chivers - send Mary in with a new gown, will you?
| The second lady struggles to her feet from behind the couch, completely dishevelled. Her own gown completely ripped open.
Chivers | Certainly, m'lady.
Vicar | (to the second lady) I do beg your pardon ... I must sit down.
First Lady | As I was saying, how do you find the new vicarage?
| They take their seats on the couch.
Vicar | Oh yes, certainly, yes indeed, I find the grounds delightful, and the servants most attentive and particularly the little serving maid with the great big knockers, and...
| He throws himself on the hostess across the tea table, knocking it over and they disappear over the back of the hostess's chair. Grunts etc. Enter Dickie applauding. Also, we hear audience applause.
Dickie | Well, there we are, another year has been too soon alas ended and I think none more than myself can be happier at this time than I ... am.
| The cast of the sketch stand in a line at the back, looking awkward and smiling. Fade out.